==> zio-aws-cloudcontrol_2.13-5.17.116.1-sources.jar: zio/aws/cloudcontrol/model/package.scala <==
package zio.aws.cloudcontrol
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.cloudcontrol.model.primitives.Identifier.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.cloudcontrol.model.primitives.ClientToken.Type
    object HandlerNextToken extends Subtype[String]
    type HandlerNextToken =
      zio.aws.cloudcontrol.model.primitives.HandlerNextToken.Type
    object Identifier extends Subtype[String]
    type Identifier = zio.aws.cloudcontrol.model.primitives.Identifier.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.cloudcontrol.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.cloudcontrol.model.primitives.NextToken.Type
    object PatchDocument extends Subtype[String]
    type PatchDocument =
      zio.aws.cloudcontrol.model.primitives.PatchDocument.Type
    object Properties extends Subtype[String]
    type Properties = zio.aws.cloudcontrol.model.primitives.Properties.Type
    object RequestToken extends Subtype[String]
    type RequestToken = zio.aws.cloudcontrol.model.primitives.RequestToken.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.cloudcontrol.model.primitives.RoleArn.Type
    object StatusMessage extends Subtype[String]
    type StatusMessage =
      zio.aws.cloudcontrol.model.primitives.StatusMessage.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.cloudcontrol.model.primitives.Timestamp.Type
    object TypeName extends Subtype[String]
    type TypeName = zio.aws.cloudcontrol.model.primitives.TypeName.Type
    object TypeVersionId extends Subtype[String]
    type TypeVersionId =
      zio.aws.cloudcontrol.model.primitives.TypeVersionId.Type
  }
  type OperationStatuses = List[zio.aws.cloudcontrol.model.OperationStatus]
  type Operations = List[zio.aws.cloudcontrol.model.Operation]
  type ResourceDescriptions =
    List[zio.aws.cloudcontrol.model.ResourceDescription]
  type ResourceRequestStatusSummaries =
    List[zio.aws.cloudcontrol.model.ProgressEvent]
}

==> zio-aws-cloudcontrol_3-5.17.217.1-sources.jar: zio/aws/cloudcontrol/model/package.scala <==
package zio.aws.cloudcontrol
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.cloudcontrol.model.primitives.Identifier.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.cloudcontrol.model.primitives.ClientToken.Type
    object HandlerNextToken extends Subtype[String]
    type HandlerNextToken =
      zio.aws.cloudcontrol.model.primitives.HandlerNextToken.Type
    object Identifier extends Subtype[String]
    type Identifier = zio.aws.cloudcontrol.model.primitives.Identifier.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.cloudcontrol.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.cloudcontrol.model.primitives.NextToken.Type
    object PatchDocument extends Subtype[String]
    type PatchDocument =
      zio.aws.cloudcontrol.model.primitives.PatchDocument.Type
    object Properties extends Subtype[String]
    type Properties = zio.aws.cloudcontrol.model.primitives.Properties.Type
    object RequestToken extends Subtype[String]
    type RequestToken = zio.aws.cloudcontrol.model.primitives.RequestToken.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.cloudcontrol.model.primitives.RoleArn.Type
    object StatusMessage extends Subtype[String]
    type StatusMessage =
      zio.aws.cloudcontrol.model.primitives.StatusMessage.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.cloudcontrol.model.primitives.Timestamp.Type
    object TypeName extends Subtype[String]
    type TypeName = zio.aws.cloudcontrol.model.primitives.TypeName.Type
    object TypeVersionId extends Subtype[String]
    type TypeVersionId =
      zio.aws.cloudcontrol.model.primitives.TypeVersionId.Type
  }
  type OperationStatuses = List[zio.aws.cloudcontrol.model.OperationStatus]
  type Operations = List[zio.aws.cloudcontrol.model.Operation]
  type ResourceDescriptions =
    List[zio.aws.cloudcontrol.model.ResourceDescription]
  type ResourceRequestStatusSummaries =
    List[zio.aws.cloudcontrol.model.ProgressEvent]
}
